@@ -49,11 +49,19 @@ Submodules
 
 """
 
-from .version import __version__
+from qiskit.algorithms.minimum_eigen_solvers.minimum_eigen_solver import (
+    ListOrDict as ListOrDictType,
+)
+
 from .exceptions import QiskitNatureError, UnsupportMethodError
+from .settings import settings
+from .version import __version__
+
 
 __all__ = [
     "__version__",
+    "ListOrDictType",
     "QiskitNatureError",
     "UnsupportMethodError",
+    "settings",
 ]
