@@ -83,7 +83,7 @@ class BOPESSampler:
                 if not isinstance(self._extrapolator, WindowExtrapolator):
                     raise QiskitNatureError(
                         "If num_bootstrap >= 2 then the extrapolator must be an instance "
-                        "of WindowExtrapolator, got {} instead".format(self._extrapolator)
+                        f"of WindowExtrapolator, got {self._extrapolator} instead"
                     )
                 self._num_bootstrap = num_bootstrap
                 self._extrapolator.window = num_bootstrap  # window for extrapolator
@@ -154,9 +154,9 @@ class BOPESSampler:
         Returns:
             The results for all points.
         """
-        raw_results = dict()  # type: Dict[float, EigenstateResult]
+        raw_results: Dict[float, EigenstateResult] = {}
         if isinstance(self._gss.solver, VariationalAlgorithm):  # type: ignore
-            self._points_optparams = dict()
+            self._points_optparams = {}
             self._gss.solver.initial_point = self._initial_point  # type: ignore
 
         # Iterate over the points
