@@ -55,16 +55,16 @@ class FCIDumpDriver(FermionicDriver):
         super().__init__()
 
         if not isinstance(fcidump_input, str):
-            raise QiskitNatureError("The fcidump_input must be str, not '{}'".format(fcidump_input))
+            raise QiskitNatureError(f"The fcidump_input must be str, not '{fcidump_input}'")
         self._fcidump_input = fcidump_input
 
         if (
             atoms
             and not isinstance(atoms, list)
-            and not all(sym in QMolecule.symbols for sym in atoms)
+            and not all(sym in QMolecule.symbols for sym in atoms)  # type: ignore
         ):
             raise QiskitNatureError(
-                "The atoms must be a list of valid atomic symbols, not '{}'".format(atoms)
+                f"The atoms must be a list of valid atomic symbols, not '{atoms}'"
             )
         self.atoms = atoms
 
