@@ -34,10 +34,10 @@ def parse(fcidump: str) -> Dict[str, Any]:
         A dictionary storing the parsed data.
     """
     try:
-        with open(fcidump, "r") as file:
+        with open(fcidump, "r", encoding="utf8") as file:
             fcidump_str = file.read()
     except OSError as ex:
-        raise QiskitNatureError("Input file '{}' cannot be read!".format(fcidump)) from ex
+        raise QiskitNatureError(f"Input file '{fcidump}' cannot be read!") from ex
 
     output = {}  # type: Dict[str, Any]
 
@@ -93,7 +93,7 @@ def parse(fcidump: str) -> Dict[str, Any]:
     # can distinguish between unrestricted and restricted FCIDump files.
     _uhf = bool(
         re.search(
-            r".*(\s+{}\s+{}\s+0\s+0)".format(norb * 2, norb * 2),
+            fr".*(\s+{norb * 2}\s+{norb * 2}\s+0\s+0)",
             fcidump_str[namelist_end.start(0) :],
         )
     )
@@ -143,10 +143,7 @@ def parse(fcidump: str) -> Dict[str, Any]:
                     hij_b[i - 1 - norb][a - 1 - norb] = x
                 else:
                     raise QiskitNatureError(
-                        "Unkown 1-electron integral indices encountered in \
-                            '{}'".format(
-                            (i, a)
-                        )
+                        "Unkown 1-electron integral indices encountered in " f"'{(i, a)}'"
                     ) from ex
         else:
             try:
@@ -166,10 +163,7 @@ def parse(fcidump: str) -> Dict[str, Any]:
                             hijkl_bb[i - 1 - norb][a - 1 - norb][j - 1 - norb][b - 1 - norb] = x
                 else:
                     raise QiskitNatureError(
-                        "Unkown 2-electron integral indices encountered in \
-                            '{}'".format(
-                            (i, a, j, b)
-                        )
+                        "Unkown 2-electron integral indices encountered in " f"'{(i, a, j, b)}'"
                     ) from ex
 
     # iterate over still empty elements in 1-electron matrix and populate with symmetric ones
