@@ -56,7 +56,7 @@ class GaussianLogDriver(BaseDriver):
         GaussianLogDriver._check_valid()
 
         if not isinstance(jcf, list) and not isinstance(jcf, str):
-            raise QiskitNatureError("Invalid input for Gaussian Log Driver '{}'".format(jcf))
+            raise QiskitNatureError(f"Invalid input for Gaussian Log Driver '{jcf}'")
 
         if isinstance(jcf, list):
             jcf = "\n".join(jcf)
