@@ -29,9 +29,8 @@ def check_valid() -> None:
     """Checks if Gaussian is installed and available"""
     if _G16PROG is None:
         raise QiskitNatureError(
-            "Could not locate {} executable '{}'. Please check that it is installed correctly.".format(
-                _GAUSSIAN_16_DESC, _GAUSSIAN_16
-            )
+            f"Could not locate {_GAUSSIAN_16_DESC} executable '{_GAUSSIAN_16}'. "
+            "Please check that it is installed correctly."
         )
 
 
@@ -59,7 +58,7 @@ def run_g16(cfg: str) -> str:
         if process is not None:
             process.kill()
 
-        raise QiskitNatureError("{} run has failed".format(_GAUSSIAN_16_DESC)) from ex
+        raise QiskitNatureError(f"{_GAUSSIAN_16_DESC} run has failed") from ex
 
     if process.returncode != 0:
         errmsg = ""
@@ -72,7 +71,7 @@ def run_g16(cfg: str) -> str:
                 logger.error(lines[i])
                 errmsg += lines[i] + "\n"
         raise QiskitNatureError(
-            "{} process return code {}\n{}".format(_GAUSSIAN_16_DESC, process.returncode, errmsg)
+            f"{_GAUSSIAN_16_DESC} process return code { process.returncode}\n{errmsg}"
         )
 
     all_text = ""
