@@ -19,6 +19,9 @@ import warnings
 from typing import List
 
 import numpy
+from ..deprecation import DeprecatedType, warn_deprecated
+
+TWOE_TO_SPIN_SUBSCRIPT = "ijkl->ljik"
 
 with warnings.catch_warnings():
     warnings.filterwarnings("ignore", category=FutureWarning)
@@ -28,8 +31,7 @@ logger = logging.getLogger(__name__)
 
 
 class QMolecule:
-    """
-    Molecule data class containing driver result.
+    """**DEPRECATED** Molecule data class containing driver result.
 
     When one of the chemistry :mod:`~qiskit_nature.drivers` is run and instance
     of this class is returned. This contains various properties that are made available in
@@ -45,6 +47,17 @@ class QMolecule:
     QMOLECULE_VERSION = 3
 
     def __init__(self, filename=None):
+        warn_deprecated(
+            "0.2.0",
+            DeprecatedType.CLASS,
+            "QMolecule",
+            additional_msg=(
+                "Instead look towards the qiskit_nature.properties.second_quantization.electronic "
+                "module. The new return object for drivers is the ElectronicStructureDriverResult "
+                "which you can construct from a QMolecule via the `from_legacy_driver_result()` "
+                "method."
+            ),
+        )
         self._filename = filename
 
         # All the following fields are saved/loaded in the save/load methods.
@@ -121,37 +134,39 @@ class QMolecule:
 
     @property
     def one_body_integrals(self):
-        """ Returns one body electron integrals. """
+        """Returns one body electron integrals."""
         return QMolecule.onee_to_spin(self.mo_onee_ints, self.mo_onee_ints_b)
 
     @property
     def two_body_integrals(self):
-        """ Returns two body electron integrals. """
+        """Returns two body electron integrals."""
         return QMolecule.twoe_to_spin(self.mo_eri_ints, self.mo_eri_ints_bb, self.mo_eri_ints_ba)
 
     def has_dipole_integrals(self):
-        """ Check if dipole integrals are present. """
-        return self.x_dip_mo_ints is not None and \
-            self.y_dip_mo_ints is not None and \
-            self.z_dip_mo_ints is not None
+        """Check if dipole integrals are present."""
+        return (
+            self.x_dip_mo_ints is not None
+            and self.y_dip_mo_ints is not None
+            and self.z_dip_mo_ints is not None
+        )
 
     @property
     def x_dipole_integrals(self):
-        """ returns x_dipole_integrals """
+        """returns x_dipole_integrals"""
         return QMolecule.onee_to_spin(self.x_dip_mo_ints, self.x_dip_mo_ints_b)
 
     @property
     def y_dipole_integrals(self):
-        """ returns y_dipole_integrals """
+        """returns y_dipole_integrals"""
         return QMolecule.onee_to_spin(self.y_dip_mo_ints, self.y_dip_mo_ints_b)
 
     @property
     def z_dipole_integrals(self):
-        """ returns z_dipole_integrals """
+        """returns z_dipole_integrals"""
         return QMolecule.onee_to_spin(self.z_dip_mo_ints, self.z_dip_mo_ints_b)
 
     def Z(self, natom):  # pylint: disable=invalid-name
-        """ Z """
+        """Z"""
         if natom < 0 or natom >= self.num_atoms:
             raise ValueError("Atom index out of range")
         return QMolecule.symbols.index(self.atom_symbol[natom].lower().capitalize())
@@ -184,9 +199,9 @@ class QMolecule:
 
     @property
     def filename(self):
-        """ returns temp file path """
+        """returns temp file path"""
         if self._filename is None:
-            file, self._filename = tempfile.mkstemp(suffix='.hdf5')
+            file, self._filename = tempfile.mkstemp(suffix=".hdf5")
             os.close(file)
 
         return self._filename
@@ -198,6 +213,7 @@ class QMolecule:
                 return
 
             with h5py.File(self._filename, "r") as file:
+
                 def read_array(name):
                     _data = file[name][...]
                     if _data.dtype == numpy.bool_ and _data.size == 1 and not _data:
@@ -214,19 +230,19 @@ class QMolecule:
                 # A version field was added to save format from version 2 so if
                 # there is no version then we have original (version 1) format
                 version = 1
-                if 'version' in file.keys():
+                if "version" in file.keys():
                     data = file["version"][...]
                     version = int(data) if data.dtype.num != 0 else version
 
                 # Origin driver info
                 data = file["origin_driver/name"][...]
-                self.origin_driver_name = data[...].tobytes().decode('utf-8')
-                self.origin_driver_version = '?'
+                self.origin_driver_name = data[...].tobytes().decode("utf-8")
+                self.origin_driver_version = "?"
                 if version > 1:
                     data = file["origin_driver/version"][...]
-                    self.origin_driver_version = data[...].tobytes().decode('utf-8')
+                    self.origin_driver_version = data[...].tobytes().decode("utf-8")
                 data = file["origin_driver/config"][...]
-                self.origin_driver_config = data[...].tobytes().decode('utf-8')
+                self.origin_driver_config = data[...].tobytes().decode("utf-8")
 
                 # Energies
                 data = file["energy/hf_energy"][...]
@@ -259,8 +275,9 @@ class QMolecule:
                 self.mo_coeff = read_array("orbitals/mo_coeff")
                 self.mo_coeff_b = read_array("orbitals/mo_coeff_B") if version > 1 else None
                 self.orbital_energies = read_array("orbitals/orbital_energies")
-                self.orbital_energies_b = \
+                self.orbital_energies_b = (
                     read_array("orbitals/orbital_energies_B") if version > 1 else None
+                )
                 self.mo_occ = read_array("orbitals/mo_occ") if version > 2 else None
                 self.mo_occ_b = read_array("orbitals/mo_occ_B") if version > 2 else None
 
@@ -272,7 +289,7 @@ class QMolecule:
                 data = file["geometry/num_atoms"][...]
                 self.num_atoms = int(data) if data.dtype.num != 0 else None
                 data = file["geometry/atom_symbol"][...]
-                self.atom_symbol = [a.decode('utf8') for a in data]
+                self.atom_symbol = [a.decode("utf8") for a in data]
                 self.atom_xyz = file["geometry/atom_xyz"][...]
 
                 # 1 and 2 electron integrals in AO basis
@@ -284,13 +301,16 @@ class QMolecule:
 
                 # 1 and 2 electron integrals in MO basis
                 self.mo_onee_ints = read_array("integrals/mo_onee_ints")
-                self.mo_onee_ints_b = \
+                self.mo_onee_ints_b = (
                     read_array("integrals/mo_onee_ints_B") if version > 1 else None
+                )
                 self.mo_eri_ints = read_array("integrals/mo_eri_ints")
-                self.mo_eri_ints_bb = \
+                self.mo_eri_ints_bb = (
                     read_array("integrals/mo_eri_ints_BB") if version > 1 else None
-                self.mo_eri_ints_ba = \
+                )
+                self.mo_eri_ints_ba = (
                     read_array("integrals/mo_eri_ints_BA") if version > 1 else None
+                )
 
                 # dipole integrals in AO basis
                 self.x_dip_ints = read_array("dipole/x_dip_ints") if version > 1 else None
@@ -321,6 +341,7 @@ class QMolecule:
             self.remove_file()
 
         with h5py.File(file, "w") as file:
+
             def create_dataset(group, name, value):
                 def is_float(v):
                     if v is None:
@@ -349,14 +370,29 @@ class QMolecule:
             # Driver origin of molecule data
             g_driver = file.create_group("origin_driver")
             g_driver.create_dataset(
-                "name", data=(numpy.string_(self.origin_driver_name)
-                              if self.origin_driver_name is not None else numpy.string_("?")))
+                "name",
+                data=(
+                    numpy.string_(self.origin_driver_name)
+                    if self.origin_driver_name is not None
+                    else numpy.string_("?")
+                ),
+            )
             g_driver.create_dataset(
-                "version", data=(numpy.string_(self.origin_driver_version)
-                                 if self.origin_driver_version is not None else numpy.string_("?")))
+                "version",
+                data=(
+                    numpy.string_(self.origin_driver_version)
+                    if self.origin_driver_version is not None
+                    else numpy.string_("?")
+                ),
+            )
             g_driver.create_dataset(
-                "config", data=(numpy.string_(self.origin_driver_config)
-                                if self.origin_driver_config is not None else numpy.string_("?")))
+                "config",
+                data=(
+                    numpy.string_(self.origin_driver_config)
+                    if self.origin_driver_config is not None
+                    else numpy.string_("?")
+                ),
+            )
 
             # Energies
             g_energy = file.create_group("energy")
@@ -385,8 +421,13 @@ class QMolecule:
             create_dataset(g_geometry, "multiplicity", self.multiplicity)
             create_dataset(g_geometry, "num_atoms", self.num_atoms)
             g_geometry.create_dataset(
-                "atom_symbol", data=([a.encode('utf8') for a in self.atom_symbol]
-                                     if self.atom_symbol is not None else False))
+                "atom_symbol",
+                data=(
+                    [a.encode("utf8") for a in self.atom_symbol]
+                    if self.atom_symbol is not None
+                    else False
+                ),
+            )
             create_dataset(g_geometry, "atom_xyz", self.atom_xyz)
 
             # 1 and 2 electron integrals
@@ -417,14 +458,14 @@ class QMolecule:
             create_dataset(g_dipole, "reverse_dipole_sign", self.reverse_dipole_sign)
 
     def remove_file(self, file_name=None):
-        """ remove file """
+        """remove file"""
         try:
             file = self._filename if file_name is None else file_name
             os.remove(file)
         except OSError:
             pass
 
-    # Utility functions to convert integrals into the form expected by Qiskit's chemistry module
+    # Utility functions to convert integrals into the form expected by Qiskit Nature
 
     @staticmethod
     def oneeints2mo(ints, moc):
@@ -457,21 +498,21 @@ class QMolecule:
         eri_mo = numpy.zeros((dim, dim, dim, dim))
 
         for a_i in range(dim):
-            temp1 = numpy.einsum('i,i...->...', moc[:, a_i], ints)
+            temp1 = numpy.einsum("i,i...->...", moc[:, a_i], ints)
             for b_i in range(dim):
-                temp2 = numpy.einsum('j,j...->...', moc[:, b_i], temp1)
-                temp3 = numpy.einsum('kc,k...->...c', moc, temp2)
-                eri_mo[a_i, b_i, :, :] = numpy.einsum('ld,l...c->...cd', moc, temp3)
+                temp2 = numpy.einsum("j,j...->...", moc[:, b_i], temp1)
+                temp3 = numpy.einsum("kc,k...->...c", moc, temp2)
+                eri_mo[a_i, b_i, :, :] = numpy.einsum("ld,l...c->...cd", moc, temp3)
 
         return eri_mo
 
     @staticmethod
     def twoeints2mo_general(ints, moc1, moc2, moc3, moc4):
-        """ twoeints2mo_general """
-        return numpy.einsum('pqrs,pi,qj,rk,sl->ijkl', ints, moc1, moc2, moc3, moc4)
+        """twoeints2mo_general"""
+        return numpy.einsum("pqrs,pi,qj,rk,sl->ijkl", ints, moc1, moc2, moc3, moc4)
 
     @staticmethod
-    def onee_to_spin(mohij, mohij_b=None, threshold=1E-12):
+    def onee_to_spin(mohij, mohij_b=None, threshold=1e-12):
         """Convert one-body MO integrals to spin orbital basis
 
         Takes one body integrals in molecular orbital basis and returns
@@ -490,14 +531,14 @@ class QMolecule:
 
         # The number of spin orbitals is twice the number of orbitals
         norbs = mohij.shape[0]
-        nspin_orbs = 2*norbs
+        nspin_orbs = 2 * norbs
 
         # One electron terms
         moh1_qubit = numpy.zeros([nspin_orbs, nspin_orbs])
         for p in range(nspin_orbs):  # pylint: disable=invalid-name
             for q in range(nspin_orbs):
-                spinp = int(p/norbs)
-                spinq = int(q/norbs)
+                spinp = int(p / norbs)
+                spinq = int(q / norbs)
                 if spinp % 2 != spinq % 2:
                     continue
                 ints = mohij if spinp == 0 else mohij_b
@@ -509,7 +550,7 @@ class QMolecule:
         return moh1_qubit
 
     @staticmethod
-    def twoe_to_spin(mohijkl, mohijkl_bb=None, mohijkl_ba=None, threshold=1E-12):
+    def twoe_to_spin(mohijkl, mohijkl_bb=None, mohijkl_ba=None, threshold=1e-12):
         """Convert two-body MO integrals to spin orbital basis
 
         Takes two body integrals in molecular orbital basis and returns
@@ -524,18 +565,18 @@ class QMolecule:
         Returns:
             numpy.ndarray: Two body integrals in spin orbitals
         """
-        ints_aa = numpy.einsum('ijkl->ljik', mohijkl)
+        ints_aa = numpy.einsum(TWOE_TO_SPIN_SUBSCRIPT, mohijkl)
 
         if mohijkl_bb is None or mohijkl_ba is None:
             ints_bb = ints_ba = ints_ab = ints_aa
         else:
-            ints_bb = numpy.einsum('ijkl->ljik', mohijkl_bb)
-            ints_ba = numpy.einsum('ijkl->ljik', mohijkl_ba)
-            ints_ab = numpy.einsum('ijkl->ljik', mohijkl_ba.transpose())
+            ints_bb = numpy.einsum(TWOE_TO_SPIN_SUBSCRIPT, mohijkl_bb)
+            ints_ba = numpy.einsum(TWOE_TO_SPIN_SUBSCRIPT, mohijkl_ba)
+            ints_ab = numpy.einsum(TWOE_TO_SPIN_SUBSCRIPT, mohijkl_ba.transpose())
 
         # The number of spin orbitals is twice the number of orbitals
         norbs = mohijkl.shape[0]
-        nspin_orbs = 2*norbs
+        nspin_orbs = 2 * norbs
 
         # The spin orbitals are mapped in the following way:
         #       Orbital zero, spin up mapped to qubit 0
@@ -555,10 +596,10 @@ class QMolecule:
             for q in range(nspin_orbs):
                 for r in range(nspin_orbs):
                     for s in range(nspin_orbs):  # pylint: disable=invalid-name
-                        spinp = int(p/norbs)
-                        spinq = int(q/norbs)
-                        spinr = int(r/norbs)
-                        spins = int(s/norbs)
+                        spinp = int(p / norbs)
+                        spinq = int(q / norbs)
+                        spinr = int(r / norbs)
+                        spins = int(s / norbs)
                         if spinp != spins:
                             continue
                         if spinq != spinr:
@@ -572,32 +613,138 @@ class QMolecule:
                         orbr = int(r % norbs)
                         orbs = int(s % norbs)
                         if abs(ints[orbp, orbq, orbr, orbs]) > threshold:
-                            moh2_qubit[p, q, r, s] = -0.5*ints[orbp, orbq, orbr, orbs]
+                            moh2_qubit[p, q, r, s] = -0.5 * ints[orbp, orbq, orbr, orbs]
 
         return moh2_qubit
 
     symbols = [
         # pylint: disable=bad-option-value,bad-whitespace
-        '_',
-        'H',  'He',
-        'Li', 'Be', 'B',  'C',  'N',  'O',  'F',  'Ne',
-        'Na', 'Mg', 'Al', 'Si', 'P',  'S',  'Cl', 'Ar',
-        'K',  'Ca', 'Sc', 'Ti', 'V',  'Cr', 'Mn', 'Fe', 'Co', 'Ni', 'Cu', 'Zn', 'Ga',
-        'Ge', 'As', 'Se', 'Br', 'Kr',
-        'Rb', 'Sr', 'Y',  'Zr', 'Nb', 'Mo', 'Tc', 'Ru', 'Rh', 'Pd', 'Ag', 'Cd', 'In',
-        'Sn', 'Sb', 'Te', 'I', 'Xe',
-        'Cs', 'Ba',
-        'La', 'Ce', 'Pr', 'Nd', 'Pm', 'Sm', 'Eu', 'Gd', 'Tb', 'Dy', 'Ho', 'Er', 'Tm', 'Yb', 'Lu',
-        'Hf', 'Ta', 'W',  'Re', 'Os', 'Ir', 'Pt', 'Au', 'Hg', 'Tl', 'Pb', 'Bi', 'Po', 'At', 'Rn',
-        'Fr', 'Ra',
-        'Ac', 'Th', 'Pa', 'U',  'Np', 'Pu', 'Am', 'Cm', 'Bk', 'Cf', 'Es', 'Fm', 'Md', 'No', 'Lr',
-        'Rf', 'Db', 'Sg', 'Bh', 'Hs', 'Mt', 'Ds', 'Rg', 'Cn', 'Nh', 'Fl', 'Mc', 'Lv', 'Ts', 'Og']
+        "_",
+        "H",
+        "He",
+        "Li",
+        "Be",
+        "B",
+        "C",
+        "N",
+        "O",
+        "F",
+        "Ne",
+        "Na",
+        "Mg",
+        "Al",
+        "Si",
+        "P",
+        "S",
+        "Cl",
+        "Ar",
+        "K",
+        "Ca",
+        "Sc",
+        "Ti",
+        "V",
+        "Cr",
+        "Mn",
+        "Fe",
+        "Co",
+        "Ni",
+        "Cu",
+        "Zn",
+        "Ga",
+        "Ge",
+        "As",
+        "Se",
+        "Br",
+        "Kr",
+        "Rb",
+        "Sr",
+        "Y",
+        "Zr",
+        "Nb",
+        "Mo",
+        "Tc",
+        "Ru",
+        "Rh",
+        "Pd",
+        "Ag",
+        "Cd",
+        "In",
+        "Sn",
+        "Sb",
+        "Te",
+        "I",
+        "Xe",
+        "Cs",
+        "Ba",
+        "La",
+        "Ce",
+        "Pr",
+        "Nd",
+        "Pm",
+        "Sm",
+        "Eu",
+        "Gd",
+        "Tb",
+        "Dy",
+        "Ho",
+        "Er",
+        "Tm",
+        "Yb",
+        "Lu",
+        "Hf",
+        "Ta",
+        "W",
+        "Re",
+        "Os",
+        "Ir",
+        "Pt",
+        "Au",
+        "Hg",
+        "Tl",
+        "Pb",
+        "Bi",
+        "Po",
+        "At",
+        "Rn",
+        "Fr",
+        "Ra",
+        "Ac",
+        "Th",
+        "Pa",
+        "U",
+        "Np",
+        "Pu",
+        "Am",
+        "Cm",
+        "Bk",
+        "Cf",
+        "Es",
+        "Fm",
+        "Md",
+        "No",
+        "Lr",
+        "Rf",
+        "Db",
+        "Sg",
+        "Bh",
+        "Hs",
+        "Mt",
+        "Ds",
+        "Rg",
+        "Cn",
+        "Nh",
+        "Fl",
+        "Mc",
+        "Lv",
+        "Ts",
+        "Og",
+    ]
 
     BOHR = 0.52917721092  # No of Angstroms in Bohr (from 2010 CODATA)
-    DEBYE = 0.393430307   # No ea0 in Debye. Use to convert our dipole moment numbers to Debye
+    DEBYE = 0.393430307  # No ea0 in Debye. Use to convert our dipole moment numbers to Debye
 
     def log(self):
-        """ log properties """
+        """log properties"""
         if not logger.isEnabledFor(logging.INFO):
             return
         opts = numpy.get_printoptions()
@@ -614,18 +761,23 @@ class QMolecule:
             logger.info("Nuclear repulsion energy: %s", self.nuclear_repulsion_energy)
             logger.info("Energy shift due to transformations: %s", self.energy_shift)
             if None not in (self.hf_energy, self.nuclear_repulsion_energy):
-                logger.info("One and two electron Hartree-Fock energy: %s",
-                            self.hf_energy - self.nuclear_repulsion_energy)
+                logger.info(
+                    "One and two electron Hartree-Fock energy: %s",
+                    self.hf_energy - self.nuclear_repulsion_energy,
+                )
             logger.info("Number of orbitals is %s", self.num_molecular_orbitals)
             logger.info("%s alpha and %s beta electrons", self.num_alpha, self.num_beta)
             logger.info("Molecule comprises %s atoms and in xyz format is ::", self.num_atoms)
             logger.info("  %s, %s", self.molecular_charge, self.multiplicity)
             if self.num_atoms is not None:
                 for n in range(0, self.num_atoms):
-                    logger.info("  %2s  %s, %s, %s", self.atom_symbol[n],
-                                self.atom_xyz[n][0] * QMolecule.BOHR,
-                                self.atom_xyz[n][1] * QMolecule.BOHR,
-                                self.atom_xyz[n][2] * QMolecule.BOHR)
+                    logger.info(
+                        "  %2s  %s, %s, %s",
+                        self.atom_symbol[n],
+                        self.atom_xyz[n][0] * QMolecule.BOHR,
+                        self.atom_xyz[n][1] * QMolecule.BOHR,
+                        self.atom_xyz[n][2] * QMolecule.BOHR,
+                    )
             if self.mo_coeff is not None:
                 logger.info("MO coefficients A: %s", self.mo_coeff.shape)
                 logger.debug("\n%s", self.mo_coeff)
@@ -708,8 +860,10 @@ class QMolecule:
             if self.nuclear_dipole_moment is not None:
                 logger.info("Nuclear dipole moment: %s", self.nuclear_dipole_moment)
             if self.reverse_dipole_sign is not None:
-                logger.info("Reversal of electronic dipole moment sign needed: %s",
-                            self.reverse_dipole_sign)
+                logger.info(
+                    "Reversal of electronic dipole moment sign needed: %s",
+                    self.reverse_dipole_sign,
+                )
 
             logger.info("Core orbitals list %s", self.core_orbitals)
         finally:
