@@ -15,7 +15,6 @@
 from abc import ABC, abstractmethod
 from typing import List, Tuple
 
-import numpy as np
 from qiskit.opflow import PauliSumOp
 from qiskit.quantum_info.operators import Pauli, SparsePauliOp
 
@@ -84,26 +83,32 @@ class QubitMapper(ABC):
                 f"operator register length {second_q_op.register_length}"
             )
 
-            # 0. Some utilities
+        # 0. Some utilities
 
-        def times_creation_op(position, pauli_table):
-            # The creation operator is given by 0.5*(X + 1j*Y)
-            real_part = SparsePauliOp(pauli_table[position][0], coeffs=[0.5])
-            imag_part = SparsePauliOp(pauli_table[position][1], coeffs=[0.5j])
+        times_creation_op = []
+        times_annihilation_op = []
+        times_occupation_number_op = []
+        times_emptiness_number_op = []
+        for paulis in pauli_table:
+            real_part = SparsePauliOp(paulis[0], coeffs=[0.5])
+            imag_part = SparsePauliOp(paulis[1], coeffs=[0.5j])
 
-            return real_part + imag_part
+            # The creation operator is given by 0.5*(X - 1j*Y)
+            creation_op = real_part - imag_part
+            times_creation_op.append(creation_op)
 
-        def times_annihilation_op(position, pauli_table):
-            # The annihilation operator is given by 0.5*(X - 1j*Y)
-            real_part = SparsePauliOp(pauli_table[position][0], coeffs=[0.5])
-            imag_part = SparsePauliOp(pauli_table[position][1], coeffs=[-0.5j])
+            # The annihilation operator is given by 0.5*(X + 1j*Y)
+            annihilation_op = real_part + imag_part
+            times_annihilation_op.append(annihilation_op)
 
-            return real_part + imag_part
+            # The occupation number operator N is given by `+-`.
+            times_occupation_number_op.append(creation_op.compose(annihilation_op, front=True))
 
-        # 1. Initialize an operator list with the identity scaled by the `self.coeff`
-        all_false = np.full(nmodes, False)
+            # The `emptiness number` operator E is given by `-+` = (I - N).
+            times_emptiness_number_op.append(annihilation_op.compose(creation_op, front=True))
 
-        ret_op_list = []
+        # make sure ret_op_list is not empty by including a zero op
+        ret_op_list = [SparsePauliOp("I" * nmodes, coeffs=[0])]
 
         # TODO to_list() is not an attribute of SecondQuantizedOp. Change the former to have this or
         #   change the signature above to take FermionicOp?
@@ -114,23 +119,20 @@ class QubitMapper(ABC):
         )
         for label, coeff in label_coeff_list:
 
-            ret_op = SparsePauliOp(Pauli((all_false, all_false)), coeffs=[coeff])
+            # 1. Initialize an operator list with the identity scaled by the `self.coeff`
+            ret_op = SparsePauliOp("I" * nmodes, coeffs=[coeff])
 
             # Go through the label and replace the fermion operators by their qubit-equivalent, then
             # save the respective Pauli string in the pauli_str list.
             for position, char in enumerate(label):
                 if char == "+":
-                    ret_op &= times_creation_op(position, pauli_table)
+                    ret_op = ret_op.compose(times_creation_op[position], front=True)
                 elif char == "-":
-                    ret_op &= times_annihilation_op(position, pauli_table)
+                    ret_op = ret_op.compose(times_annihilation_op[position], front=True)
                 elif char == "N":
-                    # The occupation number operator N is given by `+-`.
-                    ret_op &= times_creation_op(position, pauli_table)
-                    ret_op &= times_annihilation_op(position, pauli_table)
+                    ret_op = ret_op.compose(times_occupation_number_op[position], front=True)
                 elif char == "E":
-                    # The `emptiness number` operator E is given by `-+` = (I - N).
-                    ret_op &= times_annihilation_op(position, pauli_table)
-                    ret_op &= times_creation_op(position, pauli_table)
+                    ret_op = ret_op.compose(times_emptiness_number_op[position], front=True)
                 elif char == "I":
                     continue
 
@@ -141,5 +143,4 @@ class QubitMapper(ABC):
                     )
             ret_op_list.append(ret_op)
 
-        zero_op = SparsePauliOp(Pauli((all_false, all_false)), coeffs=[0])
-        return PauliSumOp(sum(ret_op_list, zero_op)).reduce()
+        return PauliSumOp(SparsePauliOp.sum(ret_op_list).simplify())
