@@ -34,8 +34,8 @@ from .spin_op import SpinOp
 from .vibrational_op import VibrationalOp
 
 __all__ = [
-    'FermionicOp',
-    'SecondQuantizedOp',
-    'SpinOp',
-    'VibrationalOp',
+    "FermionicOp",
+    "SecondQuantizedOp",
+    "SpinOp",
+    "VibrationalOp",
 ]
