@@ -1,6 +1,6 @@
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2021.
+# (C) Copyright IBM 2021, 2022.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -19,6 +19,7 @@ from itertools import product
 from typing import List, Optional, Tuple, Union
 
 import numpy as np
+from scipy.sparse import csc_matrix
 
 from qiskit_nature.operators.second_quantization.second_quantized_op import SecondQuantizedOp
 
@@ -291,6 +292,8 @@ class FermionicOp(SecondQuantizedOp):
                     )
                     for label, coeff in data
                 ]
+                if register_length is None:
+                    register_length = max(len(label) for label, _ in data)
             else:
                 self._data = [
                     (
@@ -302,14 +305,16 @@ class FermionicOp(SecondQuantizedOp):
                     for label, coeff in data
                 ]
 
-            if register_length is not None:
+            if register_length is None:
+                self._register_length = (
+                    max(max((p.index for p in l), default=0) for l, _ in self._data) + 1
+                )
+            else:
                 self._register_length = register_length
 
     def _substituted_label(self, label):
-        max_index = 0
         new_label = []
         for c, index in label:
-            max_index = max(max_index, index)
             if c == "+":
                 new_label.append(_FermionLabelPrimitive(True, index))
             elif c == "-":
@@ -325,7 +330,6 @@ class FermionicOp(SecondQuantizedOp):
             else:
                 raise ValueError(f"Invalid label {c}_{index} is given.")
 
-        self._register_length = max_index + 1
         return new_label
 
     def __repr__(self) -> str:
@@ -464,6 +468,67 @@ class FermionicOp(SecondQuantizedOp):
             ]
         return self._to_dense_label_data()
 
+    def to_matrix(self, sparse: Optional[bool] = True) -> Union[csc_matrix, np.ndarray]:
+        """Convert to a matrix representation over the full fermionic Fock space in occupation number
+        basis. The basis states are ordered in increasing bitstring order as 0000, 0001, ..., 1111.
+
+        Args:
+            sparse: If true, the matrix is returned as a sparse csc_matrix, else it is returned as a
+            dense numpy array.
+
+        Returns:
+            The matrix of the operator in the Fock basis (scipy.sparse.csc_matrix or numpy.ndarray
+            with dtype=numpy.complex128)
+        """
+
+        csc_data, csc_col, csc_row = [], [], []
+
+        dimension = 1 << self.register_length
+
+        # loop over all columns of the matrix
+        for col_idx in range(dimension):
+            initial_occupations = [occ == "1" for occ in f"{col_idx:0{self.register_length}b}"]
+            # loop over the terms in the operator data
+            for opstring, prefactor in self.reduce()._data:
+                # check if op string is the identity
+                if not opstring:
+                    csc_data.append(prefactor)
+                    csc_row.append(col_idx)
+                    csc_col.append(col_idx)
+                else:
+                    occupations = initial_occupations.copy()
+                    sign = 1
+                    mapped_to_zero = False
+
+                    # apply terms sequentially to the current basis state
+                    for label_primitive in reversed(opstring):
+                        occ = occupations[label_primitive.index]
+                        if label_primitive.is_creation == occ:
+                            # Applying the creation operator on an occupied state maps to zero. So
+                            # does applying the annihilation operator on an unoccupied state.
+                            mapped_to_zero = True
+                            break
+                        sign *= (-1) ** sum(occupations[: label_primitive.index])
+                        occupations[label_primitive.index] = not occ
+
+                    # add data point to matrix in the correct row
+                    if not mapped_to_zero:
+                        row_idx = sum(int(occ) << idx for idx, occ in enumerate(occupations[::-1]))
+                        csc_data.append(sign * prefactor)
+                        csc_row.append(row_idx)
+                        csc_col.append(col_idx)
+
+        sparse_mat = csc_matrix(
+            (csc_data, (csc_row, csc_col)),
+            shape=(dimension, dimension),
+            dtype=complex,
+        )
+
+        if sparse:
+            return sparse_mat
+        else:
+            return sparse_mat.toarray()
+
     def adjoint(self) -> "FermionicOp":
         data = []
         for label, coeff in self._data:
@@ -594,7 +659,7 @@ class FermionicOp(SecondQuantizedOp):
         Returns:
             The zero-operator of the given length.
         """
-        return FermionicOp(("I_0", 0.0), register_length=register_length, display_format="sparse")
+        return FermionicOp(("", 0.0), register_length=register_length, display_format="sparse")
 
     @classmethod
     def one(cls, register_length: int) -> "FermionicOp":
@@ -606,4 +671,4 @@ class FermionicOp(SecondQuantizedOp):
         Returns:
             The unity-operator of the given length.
         """
-        return FermionicOp(("I_0", 1.0), register_length=register_length, display_format="sparse")
+        return FermionicOp(("", 1.0), register_length=register_length, display_format="sparse")
