@@ -11,7 +11,7 @@
 # that they have been altered from the originals.
 
 """Eigenstate results module."""
-from typing import Optional, List, Union
+from typing import Optional, List, Tuple, Union
 import inspect
 
 import numpy as np
@@ -22,6 +22,8 @@ from qiskit.result import Result
 from qiskit.algorithms import AlgorithmResult
 from qiskit.opflow import OperatorBase
 
+from qiskit_nature import ListOrDictType
+
 
 class EigenstateResult(AlgorithmResult):
     """The eigenstate result interface."""
@@ -44,7 +46,9 @@ class EigenstateResult(AlgorithmResult):
                 ]
             ]
         ] = None
-        self._aux_operator_eigenvalues: Optional[List[float]] = None
+        self._aux_operator_eigenvalues: Optional[
+            List[ListOrDictType[Tuple[complex, complex]]]
+        ] = None
         self._raw_result: Optional[AlgorithmResult] = None
 
     @property
@@ -129,12 +133,14 @@ class EigenstateResult(AlgorithmResult):
         return None
 
     @property
-    def aux_operator_eigenvalues(self) -> Optional[List[float]]:
+    def aux_operator_eigenvalues(self) -> Optional[List[ListOrDictType[Tuple[complex, complex]]]]:
         """return aux operator eigen values"""
         return self._aux_operator_eigenvalues
 
     @aux_operator_eigenvalues.setter
-    def aux_operator_eigenvalues(self, value: List[float]) -> None:
+    def aux_operator_eigenvalues(
+        self, value: List[ListOrDictType[Tuple[complex, complex]]]
+    ) -> None:
         """set aux operator eigen values"""
         self._aux_operator_eigenvalues = value
 
