@@ -12,12 +12,14 @@
 
 """ Test Numerical qEOM excited states calculation """
 
+import contextlib
+import io
 import unittest
 import warnings
 
 from test import QiskitNatureTestCase
 
-from qiskit import BasicAer
+from qiskit import Aer
 from qiskit.utils import algorithm_globals, QuantumInstance
 from qiskit.algorithms.optimizers import COBYLA
 
@@ -111,7 +113,7 @@ class TestBosonicESCCalculation(QiskitNatureTestCase):
         """Test with VQE plus UVCCSD"""
         optimizer = COBYLA(maxiter=5000)
         solver = VQEUVCCFactory(
-            QuantumInstance(BasicAer.get_backend("statevector_simulator")),
+            QuantumInstance(Aer.get_backend("aer_simulator_statevector")),
             optimizer=optimizer,
         )
         gsc = GroundStateEigensolver(self.qubit_converter, solver)
@@ -120,6 +122,28 @@ class TestBosonicESCCalculation(QiskitNatureTestCase):
         for idx, energy in enumerate(self.reference_energies):
             self.assertAlmostEqual(results.computed_vibrational_energies[idx], energy, places=1)
 
+    def test_vqe_uvccsd_with_callback(self):
+        """Test VQE UVCCSD with callback."""
+
+        def cb_callback(nfev, parameters, energy, stddev):
+            print(f"iterations {nfev}: energy: {energy}")
+
+        optimizer = COBYLA(maxiter=5000)
+        solver = VQEUVCCFactory(
+            QuantumInstance(Aer.get_backend("aer_simulator_statevector")),
+            optimizer=optimizer,
+            callback=cb_callback,
+        )
+        gsc = GroundStateEigensolver(self.qubit_converter, solver)
+        esc = QEOM(gsc, "sd")
+        with contextlib.redirect_stdout(io.StringIO()) as out:
+            results = esc.solve(self.vibrational_problem)
+        for idx, energy in enumerate(self.reference_energies):
+            self.assertAlmostEqual(results.computed_vibrational_energies[idx], energy, places=1)
+        for idx, line in enumerate(out.getvalue().split("\n")):
+            if line.strip():
+                self.assertTrue(line.startswith(f"iterations {idx+1}: energy: "))
+
 
 if __name__ == "__main__":
     unittest.main()
