@@ -21,7 +21,11 @@ from qiskit.algorithms import NumPyMinimumEigensolver, NumPyEigensolver
 
 from qiskit_nature.drivers import UnitsType
 from qiskit_nature.drivers.second_quantization import PySCFDriver
-from qiskit_nature.mappers.second_quantization import JordanWignerMapper
+from qiskit_nature.mappers.second_quantization import (
+    BravyiKitaevMapper,
+    JordanWignerMapper,
+    ParityMapper,
+)
 from qiskit_nature.converters.second_quantization import QubitConverter
 from qiskit_nature.problems.second_quantization import ElectronicStructureProblem
 from qiskit_nature.algorithms import (
@@ -75,10 +79,51 @@ class TestNumericalQEOMESCCalculation(QiskitNatureTestCase):
         for idx, energy in enumerate(self.reference_energies):
             self.assertAlmostEqual(results.computed_energies[idx], energy, places=4)
 
-    def test_vqe_mes(self):
-        """Test VQEUCCSDFactory with QEOM"""
+    def test_vqe_mes_jw(self):
+        """Test VQEUCCSDFactory with QEOM + Jordan Wigner mapping"""
+        converter = QubitConverter(JordanWignerMapper())
+        self._solve_with_vqe_mes(converter)
+
+    def test_vqe_mes_jw_auto(self):
+        """Test VQEUCCSDFactory with QEOM + Jordan Wigner mapping + auto symmetry"""
+        converter = QubitConverter(JordanWignerMapper(), z2symmetry_reduction="auto")
+        self._solve_with_vqe_mes(converter)
+
+    def test_vqe_mes_parity(self):
+        """Test VQEUCCSDFactory with QEOM + Parity mapping"""
+        converter = QubitConverter(ParityMapper())
+        self._solve_with_vqe_mes(converter)
+
+    def test_vqe_mes_parity_2q(self):
+        """Test VQEUCCSDFactory with QEOM + Parity mapping + reduction"""
+        converter = QubitConverter(ParityMapper(), two_qubit_reduction=True)
+        self._solve_with_vqe_mes(converter)
+
+    def test_vqe_mes_parity_auto(self):
+        """Test VQEUCCSDFactory with QEOM + Parity mapping + auto symmetry"""
+        converter = QubitConverter(ParityMapper(), z2symmetry_reduction="auto")
+        self._solve_with_vqe_mes(converter)
+
+    def test_vqe_mes_parity_2q_auto(self):
+        """Test VQEUCCSDFactory with QEOM + Parity mapping + reduction + auto symmetry"""
+        converter = QubitConverter(
+            ParityMapper(), two_qubit_reduction=True, z2symmetry_reduction="auto"
+        )
+        self._solve_with_vqe_mes(converter)
+
+    def test_vqe_mes_bk(self):
+        """Test VQEUCCSDFactory with QEOM + Bravyi-Kitaev mapping"""
+        converter = QubitConverter(BravyiKitaevMapper())
+        self._solve_with_vqe_mes(converter)
+
+    def test_vqe_mes_bk_auto(self):
+        """Test VQEUCCSDFactory with QEOM + Bravyi-Kitaev mapping + auto symmetry"""
+        converter = QubitConverter(BravyiKitaevMapper(), z2symmetry_reduction="auto")
+        self._solve_with_vqe_mes(converter)
+
+    def _solve_with_vqe_mes(self, converter: QubitConverter):
         solver = VQEUCCFactory(self.quantum_instance)
-        gsc = GroundStateEigensolver(self.qubit_converter, solver)
+        gsc = GroundStateEigensolver(converter, solver)
         esc = QEOM(gsc, "sd")
         results = esc.solve(self.electronic_structure_problem)
 
