@@ -65,7 +65,7 @@ class TestDriverGaussianLog(QiskitNatureTestCase):
     def test_gaussian_log_result_file(self):
         """Test result from file"""
         result = GaussianLogResult(self.logfile)
-        with open(self.logfile) as file:
+        with open(self.logfile, "r", encoding="utf8") as file:
             lines = file.read().split("\n")
 
         with self.subTest("Check list of lines"):
@@ -77,14 +77,14 @@ class TestDriverGaussianLog(QiskitNatureTestCase):
 
     def test_gaussian_log_result_list(self):
         """Test result from list of strings"""
-        with open(self.logfile) as file:
+        with open(self.logfile, "r", encoding="utf8") as file:
             lines = file.read().split("\n")
         result = GaussianLogResult(lines)
         self.assertListEqual(result.log, lines)
 
     def test_gaussian_log_result_string(self):
         """Test result from string"""
-        with open(self.logfile) as file:
+        with open(self.logfile, "r", encoding="utf8") as file:
             line = file.read()
         result = GaussianLogResult(line)
         self.assertListEqual(result.log, line.split("\n"))
@@ -166,7 +166,7 @@ class TestDriverGaussianLog(QiskitNatureTestCase):
             [2.2973803125, 3, 3, 3, 3],
         ]
         for i, entry in enumerate(watson.data):
-            msg = "mode[{}]={} does not match expected {}".format(i, entry, expected[i])
+            msg = f"mode[{i}]={entry} does not match expected {expected[i]}"
             self.assertAlmostEqual(entry[0], expected[i][0], msg=msg)
             self.assertListEqual(entry[1:], expected[i][1:], msg=msg)
 
