@@ -23,10 +23,13 @@ class TestDriverHDF5(QiskitNatureTestCase, TestDriver):
 
     def setUp(self):
         super().setUp()
-        driver = HDF5Driver(hdf5_input=self.get_resource_path('test_driver_hdf5.hdf5',
-                                                              'drivers/hdf5d'))
+        driver = HDF5Driver(
+            hdf5_input=self.get_resource_path(
+                "test_driver_hdf5.hdf5", "drivers/second_quantization/hdf5d"
+            )
+        )
         self.qmolecule = driver.run()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
