@@ -13,39 +13,36 @@
 """ Test Driver PySCF """
 
 import unittest
-from test import QiskitNatureTestCase
+from test import QiskitNatureTestCase, requires_extra_library
 from test.drivers.test_driver import TestDriver
 from qiskit_nature.drivers import PySCFDriver, UnitsType
-from qiskit_nature import QiskitNatureError
 
 
 class TestDriverPySCF(QiskitNatureTestCase, TestDriver):
     """PYSCF Driver tests."""
 
+    @requires_extra_library
     def setUp(self):
         super().setUp()
-        try:
-            driver = PySCFDriver(atom='H .0 .0 .0; H .0 .0 0.735',
-                                 unit=UnitsType.ANGSTROM,
-                                 charge=0,
-                                 spin=0,
-                                 basis='sto3g')
-        except QiskitNatureError:
-            self.skipTest('PYSCF driver does not appear to be installed')
+        driver = PySCFDriver(
+            atom="H .0 .0 .0; H .0 .0 0.735",
+            unit=UnitsType.ANGSTROM,
+            charge=0,
+            spin=0,
+            basis="sto3g",
+        )
         self.qmolecule = driver.run()
 
 
 class TestDriverPySCFMolecule(QiskitNatureTestCase, TestDriver):
     """PYSCF Driver Molecule tests."""
 
+    @requires_extra_library
     def setUp(self):
         super().setUp()
-        try:
-            driver = PySCFDriver(molecule=TestDriver.MOLECULE)
-        except QiskitNatureError:
-            self.skipTest('PYSCF driver does not appear to be installed')
+        driver = PySCFDriver(molecule=TestDriver.MOLECULE)
         self.qmolecule = driver.run()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
