@@ -13,13 +13,13 @@
 """ Test Jordan Wigner Mapper """
 
 import unittest
-
 from test import QiskitNatureTestCase
 
-from qiskit.opflow import X, Y, Z, I
+from qiskit.opflow import I, PauliSumOp, X, Y, Z
 
 from qiskit_nature.drivers.second_quantization import HDF5Driver
 from qiskit_nature.mappers.second_quantization import JordanWignerMapper
+from qiskit_nature.operators.second_quantization import FermionicOp
 
 
 class TestJordanWignerMapper(QiskitNatureTestCase):
@@ -67,6 +67,33 @@ class TestJordanWignerMapper(QiskitNatureTestCase):
         mapper = JordanWignerMapper()
         self.assertFalse(mapper.allows_two_qubit_reduction)
 
+    def test_mapping_for_single_op(self):
+        """Test for single register operator."""
+        with self.subTest("test +"):
+            op = FermionicOp("+", display_format="dense")
+            expected = PauliSumOp.from_list([("X", 0.5), ("Y", -0.5j)])
+            self.assertEqual(JordanWignerMapper().map(op), expected)
+
+        with self.subTest("test -"):
+            op = FermionicOp("-", display_format="dense")
+            expected = PauliSumOp.from_list([("X", 0.5), ("Y", 0.5j)])
+            self.assertEqual(JordanWignerMapper().map(op), expected)
+
+        with self.subTest("test N"):
+            op = FermionicOp("N", display_format="dense")
+            expected = PauliSumOp.from_list([("I", 0.5), ("Z", -0.5)])
+            self.assertEqual(JordanWignerMapper().map(op), expected)
+
+        with self.subTest("test E"):
+            op = FermionicOp("E", display_format="dense")
+            expected = PauliSumOp.from_list([("I", 0.5), ("Z", 0.5)])
+            self.assertEqual(JordanWignerMapper().map(op), expected)
+
+        with self.subTest("test I"):
+            op = FermionicOp("I", display_format="dense")
+            expected = PauliSumOp.from_list([("I", 1)])
+            self.assertEqual(JordanWignerMapper().map(op), expected)
+
 
 if __name__ == "__main__":
     unittest.main()
