@@ -13,13 +13,13 @@
 """ Test Parity Mapper """
 
 import unittest
-
 from test import QiskitNatureTestCase
 
-from qiskit.opflow import X, Z, I
+from qiskit.opflow import I, PauliSumOp, X, Z
 
 from qiskit_nature.drivers.second_quantization import HDF5Driver
 from qiskit_nature.mappers.second_quantization import ParityMapper
+from qiskit_nature.operators.second_quantization import FermionicOp
 
 
 class TestParityMapper(QiskitNatureTestCase):
@@ -67,6 +67,33 @@ class TestParityMapper(QiskitNatureTestCase):
         mapper = ParityMapper()
         self.assertTrue(mapper.allows_two_qubit_reduction)
 
+    def test_mapping_for_single_op(self):
+        """Test for single register operator."""
+        with self.subTest("test +"):
+            op = FermionicOp("+")
+            expected = PauliSumOp.from_list([("X", 0.5), ("Y", -0.5j)])
+            self.assertEqual(ParityMapper().map(op), expected)
+
+        with self.subTest("test -"):
+            op = FermionicOp("-")
+            expected = PauliSumOp.from_list([("X", 0.5), ("Y", 0.5j)])
+            self.assertEqual(ParityMapper().map(op), expected)
+
+        with self.subTest("test N"):
+            op = FermionicOp("N")
+            expected = PauliSumOp.from_list([("I", 0.5), ("Z", -0.5)])
+            self.assertEqual(ParityMapper().map(op), expected)
+
+        with self.subTest("test E"):
+            op = FermionicOp("E")
+            expected = PauliSumOp.from_list([("I", 0.5), ("Z", 0.5)])
+            self.assertEqual(ParityMapper().map(op), expected)
+
+        with self.subTest("test I"):
+            op = FermionicOp("I")
+            expected = PauliSumOp.from_list([("I", 1)])
+            self.assertEqual(ParityMapper().map(op), expected)
+
 
 if __name__ == "__main__":
     unittest.main()
