@@ -1,6 +1,6 @@
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2021.
+# (C) Copyright IBM 2021, 2022.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -18,7 +18,10 @@ from functools import lru_cache
 from itertools import product
 from test import QiskitNatureTestCase
 
+import numpy as np
 from ddt import data, ddt, unpack
+from scipy.sparse import csc_matrix
+from scipy.sparse.linalg import eigs
 
 from qiskit_nature.operators.second_quantization import FermionicOp
 
@@ -125,6 +128,11 @@ class TestFermionicOp(QiskitNatureTestCase):
         desired = FermionicOp("III", display_format="dense")
         self.assertFermionEqual(actual, desired)
 
+    def test_register_length(self):
+        """Test inference of register_length"""
+        op = FermionicOp([("+_1", 1.0), ("", 1.0)], display_format="dense")
+        self.assertEqual(op.register_length, 2)
+
     def test_neg(self):
         """Test __neg__"""
         fer_op = -FermionicOp("+N-EII", display_format="dense")
@@ -335,6 +343,64 @@ class TestFermionicOp(QiskitNatureTestCase):
         fer_op.display_format = "dense"
         self.assertNotEqual(fer_op.to_list(), str2list(label))
 
+    def test_to_matrix(self):
+        """Test to_matrix"""
+        with self.subTest("identity operator matrix"):
+            mat = FermionicOp.one(2).to_matrix(sparse=False)
+            targ = np.eye(4)
+            self.assertTrue(np.allclose(mat, targ))
+
+        with self.subTest("number operator matrix"):
+            mat = FermionicOp("IN").to_matrix(sparse=False)
+            targ = np.array([[0, 0, 0, 0], [0, 1, 0, 0], [0, 0, 0, 0], [0, 0, 0, 1]])
+            self.assertTrue(np.allclose(mat, targ))
+
+        with self.subTest("emptiness operator matrix"):
+            mat = FermionicOp("IE").to_matrix(sparse=False)
+            targ = np.array([[1, 0, 0, 0], [0, 0, 0, 0], [0, 0, 1, 0], [0, 0, 0, 0]])
+            self.assertTrue(np.allclose(mat, targ))
+
+        with self.subTest("raising operator matrix"):
+            mat = FermionicOp("I+").to_matrix(sparse=False)
+            targ = np.array([[0, 0, 0, 0], [1, 0, 0, 0], [0, 0, 0, 0], [0, 0, -1, 0]])
+            self.assertTrue(np.allclose(mat, targ))
+
+        with self.subTest("lowering operator matrix"):
+            mat = FermionicOp("I-").to_matrix(sparse=False)
+            targ = np.array([[0, 1, 0, 0], [0, 0, 0, 0], [0, 0, 0, -1], [0, 0, 0, 0]])
+            self.assertTrue(np.allclose(mat, targ))
+
+        with self.subTest("nontrivial sparse matrix"):
+            mat = FermionicOp([("ENI+", 3j), ("-N+-", -2)]).to_matrix()
+            targ = csc_matrix(([-3j, 3j, -2], ([5, 7, 6], [4, 6, 13])), shape=(16, 16))
+            self.assertTrue((mat != targ).nnz == 0)
+
+        with self.subTest("Test Hydrogen spectrum"):
+            h2_labels = [
+                ("+_0 -_1 +_2 -_3", (0.18093120148374142)),
+                ("+_0 -_1 -_2 +_3", (-0.18093120148374134)),
+                ("-_0 +_1 +_2 -_3", (-0.18093120148374134)),
+                ("-_0 +_1 -_2 +_3", (0.18093120148374128)),
+                ("+_3 -_3", (-0.4718960038869427)),
+                ("+_2 -_2", (-1.2563391028292563)),
+                ("+_2 -_2 +_3 -_3", (0.48365053378098793)),
+                ("+_1 -_1", (-0.4718960038869427)),
+                ("+_1 -_1 +_3 -_3", (0.6985737398458793)),
+                ("+_1 -_1 +_2 -_2", (0.6645817352647293)),
+                ("+_0 -_0", (-1.2563391028292563)),
+                ("+_0 -_0 +_3 -_3", (0.6645817352647293)),
+                ("+_0 -_0 +_2 -_2", (0.6757101625347564)),
+                ("+_0 -_0 +_1 -_1", (0.48365053378098793)),
+            ]
+            h2_matrix = FermionicOp(h2_labels, register_length=4).to_matrix()
+            evals, evecs = eigs(h2_matrix)
+            self.assertTrue(np.isclose(np.min(evals), -1.8572750))
+            # make sure the ground state has support only in the 2-particle subspace
+            groundstate = evecs[:, np.argmin(evals)]
+            for idx in np.where(~np.isclose(groundstate, 0))[0]:
+                binary = f"{idx:0{4}b}"
+                self.assertEqual(binary.count("1"), 2)
+
     def test_normal_order(self):
         """test normal_order method"""
         with self.subTest("Test for creation operator"):
