@@ -11,8 +11,7 @@
 # that they have been altered from the originals.
 
 """Tests Electronic Structure Problem."""
-
-from test import QiskitNatureTestCase
+from test import QiskitNatureTestCase, requires_extra_library
 from test.problems.second_quantization.electronic.resources.resource_reader import (
     read_expected_file,
 )
@@ -20,12 +19,22 @@ from test.problems.second_quantization.electronic.resources.resource_reader impo
 import warnings
 import numpy as np
 
-from qiskit_nature.drivers import HDF5Driver as LegacyHDF5Driver
-from qiskit_nature.drivers.second_quantization import HDF5Driver
+from qiskit_nature.converters.second_quantization import QubitConverter
+from qiskit_nature.drivers import HDF5Driver as LegacyHDF5Driver, Molecule
+from qiskit_nature.drivers.second_quantization import (
+    HDF5Driver,
+    PySCFDriver,
+    ElectronicStructureMoleculeDriver,
+    ElectronicStructureDriverType,
+)
+from qiskit_nature.mappers.second_quantization import ParityMapper
 from qiskit_nature.operators.second_quantization import SecondQuantizedOp
 from qiskit_nature.problems.second_quantization import ElectronicStructureProblem
 from qiskit_nature.transformers import ActiveSpaceTransformer as LegacyActiveSpaceTransformer
-from qiskit_nature.transformers.second_quantization.electronic import ActiveSpaceTransformer
+from qiskit_nature.transformers.second_quantization.electronic import (
+    ActiveSpaceTransformer,
+    FreezeCoreTransformer,
+)
 
 
 class TestElectronicStructureProblem(QiskitNatureTestCase):
@@ -144,8 +153,8 @@ class TestElectronicStructureProblemLegacyDrivers(QiskitNatureTestCase):
                 warnings.filterwarnings("ignore", category=DeprecationWarning)
                 # legacy driver used, molecule_data should not be None
                 self.assertIsNotNone(electronic_structure_problem.molecule_data)
-                # no transformer used, molecule_data_transformed should be None
-                self.assertIsNone(electronic_structure_problem.molecule_data_transformed)
+                # no transformer used, molecule_data_transformed should be set to molecule_data
+                self.assertIsNotNone(electronic_structure_problem.molecule_data_transformed)
             # converted properties should never be None
             self.assertIsNotNone(electronic_structure_problem.grouped_property)
             self.assertIsNotNone(electronic_structure_problem.grouped_property_transformed)
@@ -209,3 +218,42 @@ class TestElectronicStructureProblemLegacyDrivers(QiskitNatureTestCase):
                 s[0] == t[0] and np.isclose(s[1], t[1])
                 for s, t in zip(expected_fermionic_op, electr_sec_quant_op.to_list())
             )
+
+    @requires_extra_library
+    def test_sector_locator_h2o(self):
+        """Test sector locator."""
+        driver = PySCFDriver(
+            atom="O 0.0000 0.0000 0.1173; H 0.0000 0.07572 -0.4692;H 0.0000 -0.07572 -0.4692",
+            basis="sto-3g",
+        )
+        es_problem = ElectronicStructureProblem(driver)
+        qubit_conv = QubitConverter(
+            mapper=ParityMapper(), two_qubit_reduction=True, z2symmetry_reduction="auto"
+        )
+        qubit_conv.convert(
+            es_problem.second_q_ops()[0],
+            num_particles=es_problem.num_particles,
+            sector_locator=es_problem.symmetry_sector_locator,
+        )
+        self.assertListEqual(qubit_conv.z2symmetries.tapering_values, [1, -1])
+
+    @requires_extra_library
+    def test_sector_locator_homonuclear(self):
+        """Test sector locator."""
+        molecule = Molecule(
+            geometry=[("Li", [0.0, 0.0, 0.0]), ("Li", [0.0, 0.0, 2.771])], charge=0, multiplicity=1
+        )
+        freeze_core_transformer = FreezeCoreTransformer(True)
+        driver = ElectronicStructureMoleculeDriver(
+            molecule, basis="sto3g", driver_type=ElectronicStructureDriverType.PYSCF
+        )
+        es_problem = ElectronicStructureProblem(driver, transformers=[freeze_core_transformer])
+        qubit_conv = QubitConverter(
+            mapper=ParityMapper(), two_qubit_reduction=True, z2symmetry_reduction="auto"
+        )
+        qubit_conv.convert(
+            es_problem.second_q_ops()[0],
+            num_particles=es_problem.num_particles,
+            sector_locator=es_problem.symmetry_sector_locator,
+        )
+        self.assertListEqual(qubit_conv.z2symmetries.tapering_values, [-1, 1])
